==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Vidutinė apkrova",
    "Last minute" : "Paskutinę minutę",
    "Memory info not available" : "Atminties informacija neprieinama",
    "Total" : "Iš viso",
    "Current usage" : "Dabartinis sunaudojimas",
    "Users" : "Naudotojai",
    "Groups" : "Grupės",
    "Links" : " Nuorodos",
    "Federated sent" : "Centralizuotai išsiųstas",
    "Federated received" : "Centralizuotai gautas",
    "Last 24 hours" : "Paskutinės 24 valandos",
    "Last 1 hour" : "Paskutinė valanda",
    "Last 5 mins" : "Paskutinės 5 minutės",
    "Monitoring" : "Stebėjimas",
    "CPU load" : "Procesoriaus apkrova",
    "Memory usage" : "Atminties sunaudojimas",
    "Active users" : "Aktyvūs naudotojai",
    "Shares" : "Viešiniai",
    "Storage" : "Saugykla",
    "Users:" : "Naudotojai:",
    "Files:" : "Failai:",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory Limit:" : "Atminties limitas:",
    "Max Execution Time:" : "Maksimalus vykdymo laikas:",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "Size:" : "Dydis:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "You can connect an external monitoring tool by using this end point: " : "Jūs galite prijungti išorinį stebėjimo įrankį pasinaudodami:",
    "Server info" : "Serverio informacija",
    "You can connect a external monitoring tool by using this end point: " : "Jūs galite prijungti išorinį stebėjimo įrankį pasinaudodami:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Vidutinė apkrova",
    "Last minute" : "Paskutinę minutę",
    "Memory info not available" : "Atminties informacija neprieinama",
    "Total" : "Iš viso",
    "Current usage" : "Dabartinis sunaudojimas",
    "Users" : "Naudotojai",
    "Groups" : "Grupės",
    "Links" : " Nuorodos",
    "Federated sent" : "Centralizuotai išsiųstas",
    "Federated received" : "Centralizuotai gautas",
    "Last 24 hours" : "Paskutinės 24 valandos",
    "Last 1 hour" : "Paskutinė valanda",
    "Last 5 mins" : "Paskutinės 5 minutės",
    "Monitoring" : "Stebėjimas",
    "CPU load" : "Procesoriaus apkrova",
    "Memory usage" : "Atminties sunaudojimas",
    "Active users" : "Aktyvūs naudotojai",
    "Shares" : "Viešiniai",
    "Storage" : "Saugykla",
    "Users:" : "Naudotojai:",
    "Files:" : "Failai:",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory Limit:" : "Atminties limitas:",
    "Max Execution Time:" : "Maksimalus vykdymo laikas:",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "Size:" : "Dydis:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "You can connect an external monitoring tool by using this end point: " : "Jūs galite prijungti išorinį stebėjimo įrankį pasinaudodami:"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
